import React, { useState } from "react";
import {
  AddIcon,
  ArrowIcon,
  CloseIcon,
  KebabIcon,
  LocationIcon,
} from "../../../icons/ExportCommonIcons";
import RenameInput from "../../../ui/inputs/RenameInput";

const VersionHistory = () => {
  const userName = localStorage.getItem("userName") ?? "Anonymous";

  const initialVersions = [
    {
      versionName: "v1.0",
      timestamp: "April 09, 2025",
      savedBy: userName,
    },
  ];

  const [versions, setVersions] = useState(initialVersions);
  const [selectedVersion, setSelectedVersion] = useState(initialVersions[0]);

  const addNewVersion = () => {
    const newVersionNumber = versions.length + 1;
    const newVersion = {
      versionName: `v${newVersionNumber}.0`,
      timestamp: new Date().toLocaleDateString("en-US", {
        year: "numeric",
        month: "long",
        day: "2-digit",
      }),
      savedBy: userName,
    };

    const updated = [newVersion, ...versions];
    setVersions(updated);
    setSelectedVersion(newVersion);
  };

  const handleSelectVersion = (version: any) => {
    setSelectedVersion(version);
    const reordered = [version, ...versions.filter((v) => v !== version)];
    setVersions(reordered);
  };

  const handleTimestampChange = (newTimestamp: string, index: number) => {
    const updatedVersions = [...versions];
    updatedVersions[index].timestamp = newTimestamp;
    setVersions(updatedVersions);
  };

  return (
    <div className="version-history-container">
      {/* Header */}
      <div className="version-history-header">
        <div className="version-history-title">Version History</div>
        <div className="version-history-icons">
          <button className="icon add-icon" onClick={addNewVersion}>
            <AddIcon />
          </button>
          <div className="icon kebab-icon">
            <KebabIcon />
          </div>
          <div className="icon close-icon">
            <CloseIcon />
          </div>
        </div>
      </div>

      {/* Shortcut Info */}
      <div className="version-history-shortcut-info">
        <div className="info-icon">i</div>
        <div className="shortcut-text">
          Press Ctrl + Alt + S to add to version history while editing
        </div>
      </div>

      {/* Current Version Display */}
      <div className="version-history-location">
        <div className="location-label">
          <LocationIcon />
        </div>
        <div className="location-details">
          <div className="current-version">
            Current Version ({selectedVersion.versionName})
          </div>
          <div className="saved-history-count">
            {versions.length} Saved History
          </div>
        </div>
      </div>

      {/* Versions List */}
      <div className="saved-versions-list">
        {versions.map((version, index) => (
          <button
            key={index}
            className="saved-version"
            onClick={() => handleSelectVersion(version)}
          >
            <div className="version-name">{version.versionName}</div>
            <div className="version-details">
              <div className="details">
                <span className="timestamp">
                  <RenameInput
                    value={version.timestamp}
                    onRename={(newTimestamp) =>
                      handleTimestampChange(newTimestamp, index)
                    }
                  />
                </span>
                <span className="saved-by">
                  <div className="user-profile">{version.savedBy[0]}</div>
                  <div className="user-name">{version.savedBy}</div>
                </span>
              </div>
              <ArrowIcon />
            </div>
          </button>
        ))}
      </div>
    </div>
  );
};

export default VersionHistory;
