import React, { useEffect } from 'react'
import { useInputValues, useProductionCapacityData, useThroughPutData } from '../../../../store/builder/store'

export default function ProductionCapacityData() {
    const { throughputData } = useThroughPutData()
    const { productionCapacityData, setProductionCapacityData } = useProductionCapacityData()
    const { inputValues } = useInputValues();

    useEffect(() => {
        if (inputValues === undefined || throughputData === undefined) return;

        const shiftLength = parseFloat(inputValues["Shift length"]);
        // console.log('shiftLength: ', shiftLength);
        const shiftsPerDay = parseFloat(inputValues["Shifts / day"]);
        // console.log('shiftsPerDay: ', shiftsPerDay);
        const workingDaysPerYear = parseFloat(inputValues["Working days / year"]);
        // console.log('workingDaysPerYear: ', workingDaysPerYear);
        const yieldRate = parseFloat(inputValues["Yield rate"]);
        // console.log('yieldRate: ', yieldRate);


        if (!isNaN(shiftLength) && !isNaN(shiftsPerDay) && !isNaN(workingDaysPerYear) && !isNaN(yieldRate) && throughputData >= 0) {
            //Daily Output
            const dailyProduction = throughputData * shiftLength * shiftsPerDay;
            console.log("DailyProduction: ", dailyProduction.toFixed(2));
            // Good units (after Yield)
            const afterYield = dailyProduction * (yieldRate / 100);
            console.log('afterYield: ', afterYield.toFixed(2));
            //Annual Output
            const annualProduction = afterYield * workingDaysPerYear;
            console.log('annualProduction: ', Number(annualProduction.toFixed(2)));
            //Production per Hour
            const productionPerHour = throughputData * (yieldRate / 100);
            console.log('productionPerHour: ', productionPerHour);
            setProductionCapacityData(Number(productionPerHour.toFixed(2)));
        }
    }, [throughputData, inputValues]);

    return (
        <></>
    )
}


